﻿using Newtonsoft.Json;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace PoEconomist.json
{
    class stash
    {
        public class Colour
        {
            public int r { get; set; }
            public int g { get; set; }
            public int b { get; set; }
        }

        public class Tab
        {
            public string n { get; set; }
            public int i { get; set; }
            public string id { get; set; }
            public string type { get; set; }
            public bool selected { get; set; }
            public Colour colour { get; set; }
            public string srcL { get; set; }
            public string srcC { get; set; }
            public string srcR { get; set; }
        }

        public class Socket
        {
            public int group { get; set; }
            public string attr { get; set; }
            public string sColour { get; set; }
        }

        public class Property
        {
            public string name { get; set; }
            public List<List<object>> values { get; set; }
            public int displayMode { get; set; }
            public int? type { get; set; }
        }

        public class Requirement
        {
            public string name { get; set; }
            public List<List<object>> values { get; set; }
            public int displayMode { get; set; }
            public string suffix { get; set; }
        }

        public class AdditionalProperty
        {
            public string name { get; set; }
            public List<List<object>> values { get; set; }
            public int displayMode { get; set; }
            public double progress { get; set; }
            public int type { get; set; }
        }

        public class NextLevelRequirement
        {
            public string name { get; set; }
            public List<List<object>> values { get; set; }
            public int displayMode { get; set; }
        }

        public class SocketedItem
        {
            public bool verified { get; set; }
            public int w { get; set; }
            public int h { get; set; }
            public string icon { get; set; }
            public bool support { get; set; }
            public string id { get; set; }
            public string name { get; set; }
            public string typeLine { get; set; }
            public bool identified { get; set; }
            public int ilvl { get; set; }
            public List<Property> properties { get; set; }
            public List<Requirement> requirements { get; set; }
            public List<AdditionalProperty> additionalProperties { get; set; }
            public List<NextLevelRequirement> nextLevelRequirements { get; set; }
            public string secDescrText { get; set; }
            public List<string> explicitMods { get; set; }
            public string descrText { get; set; }
            public int frameType { get; set; }
            public int socket { get; set; }
            public string colour { get; set; }
        }

        public class Item
        {
            public bool verified { get; set; }
            public int w { get; set; }
            public int h { get; set; }
            public string icon { get; set; }
            public string league { get; set; }
            public string id { get; set; }
            public List<Socket> sockets { get; set; }
            public string name { get; set; }
            public string typeLine { get; set; }
            public bool identified { get; set; }
            public int ilvl { get; set; }
            public bool corrupted { get; set; }
            public int frameType { get; set; }
            public int x { get; set; }
            public int y { get; set; }
            public string inventoryId { get; set; }
            public List<SocketedItem> socketedItems { get; set; }
            public List<Property> properties { get; set; }
            public List<Requirement> requirements { get; set; }
            public List<string> implicitMods { get; set; }
            public List<string> explicitMods { get; set; }
            public List<string> craftedMods { get; set; }
            public bool? support { get; set; }
            public List<AdditionalProperty> additionalProperties { get; set; }
            public string secDescrText { get; set; }
            public string descrText { get; set; }
            public List<string> flavourText { get; set; }
            public bool? fractured { get; set; }
            public List<string> fracturedMods { get; set; }
            public List<string> enchantMods { get; set; }
            public int? talismanTier { get; set; }
        }

        public class Stash
        {
            public int numTabs { get; set; }
            public List<Tab> tabs { get; set; }
            public bool quadLayout { get; set; }
            public List<Item> items { get; set; }
        }

        public static void GenItemText()
        {
            var files = Directory.GetFiles("tmp","*.txt");
            foreach (var f in files)
            {
                File.Delete(f);
            }
            Stash j = JsonConvert.DeserializeObject<Stash>(File.ReadAllText("stash.json"));
            List<string> prop = new List<string>();
            foreach (var i in j.items)
            {
                if (i.name != "" && i.frameType == 2)
                {
                    prop.Add($"Rarity: Rare");
                    prop.Add($"{i.name}");
                    prop.Add($"{i.typeLine}");
                    prop.Add("--------");
                    if (i.properties != null && i.properties.Count() > 0)
                    {
                        foreach (var p in i.properties)
                        {
                            if (p.name == "Quality")
                            {
                                prop.Add($"Quality: {p.values[0][0]}");
                            }
                            if (p.name == "Armour")
                            {
                                prop.Add($"Armour: {p.values[0][0]}");
                            }
                            if (p.name == "Energy Shield")
                            {
                                prop.Add($"Energy Shield: {p.values[0][0]}");
                            }
                            if (p.name == "Evasion Rating")
                            {
                                prop.Add($"Evasion Rating: {p.values[0][0]}");
                            }
                            if (p.values.Count() == 0)
                            {
                                prop.Add($"{p.name}");
                            }
                            if (p.name == "Physical Damage")
                            {
                                prop.Add($"Physical Damage: {p.values[0][0]}");
                            }
                            if (p.name == "Elemental Damage")
                            {
                                prop.Add($"Elemental Damage: {p.values[0][0]}");
                            }
                            if (p.name == "Critical Strike Chance")
                            {
                                prop.Add($"Critical Strike Chance: {p.values[0][0]}");
                            }
                            if (p.name == "Attacks per Second")
                            {
                                prop.Add($"Attacks per Second: {p.values[0][0]}");
                            }
                            if (p.name == "Weapon Range")
                            {
                                prop.Add($"Weapon Range: {p.values[0][0]}");
                            }
                        }
                        prop.Add("--------");
                    }
                    prop.Add("Requirements:");
                    if (i.requirements != null)
                    {
                        foreach (var r in i.requirements)
                        {
                            if (r.name == "Level")
                            {
                                prop.Add($"Level: {r.values[0][0]}");
                            }
                            if (r.name == "Str")
                            {
                                prop.Add($"Str: {r.values[0][0]}");
                            }
                            if (r.name == "Dex")
                            {
                                prop.Add($"Dex: {r.values[0][0]}");
                            }
                            if (r.name == "Int")
                            {
                                prop.Add($"Int: {r.values[0][0]}");
                            }
                        }
                    }
                    prop.Add("--------");
                    if (i.sockets != null)
                    {
                        List<string> g0 = new List<string>();
                        List<string> g1 = new List<string>();
                        List<string> g2 = new List<string>();
                        List<string> g3 = new List<string>();
                        List<string> g4 = new List<string>();
                        List<string> g5 = new List<string>();
                        foreach (var s in i.sockets)
                        {
                            if (s.group == 0)
                            {
                                g0.Add(s.sColour.ToString());
                            }
                            if (s.group == 1)
                            {
                                g1.Add(s.sColour.ToString());
                            }
                            if (s.group == 2)
                            {
                                g2.Add(s.sColour.ToString());
                            }
                            if (s.group == 3)
                            {
                                g3.Add(s.sColour.ToString());
                            }
                            if (s.group == 4)
                            {
                                g4.Add(s.sColour.ToString());
                            }
                            if (s.group == 5)
                            {
                                g5.Add(s.sColour.ToString());
                            }
                        }
                        string g0f = string.Join("-", g0);
                        string g1f = string.Join("-", g1);
                        string g2f = string.Join("-", g2);
                        string g3f = string.Join("-", g3);
                        string g4f = string.Join("-", g4);
                        string g5f = string.Join("-", g5);
                        prop.Add($"{g0f} {g1f} {g2f} {g3f} {g4f} {g5f}");
                    }
                    prop.Add("--------");
                    prop.Add($"Item Level: {i.ilvl}");
                    prop.Add("--------");
                    if (i.implicitMods != null)
                    {
                        foreach (var im in i.implicitMods)
                        {
                            prop.Add($"{im}");
                        }
                        prop.Add("--------");                       
                    }
                    if (i.explicitMods != null)
                    {
                        foreach (var em in i.explicitMods)
                        {
                            prop.Add($"{em}");
                        }
                    }


                    msg.CMW($"{i.name} - {i.typeLine}",true,1);
                    File.WriteAllLines($@"tmp\{i.id.Substring(0, Math.Min(10, i.id.Length))}_{i.name}_{i.typeLine}.txt", prop);
                    prop.Clear();
                }
            }
        }
    }
}
